<?php

namespace PAR\Controller;

use PAR\Controller\PARCrud;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use PAR\Service\BusinessPartnerService;
use PAR\Traits\TResponse;


class BusinessPartnerController extends PARCrud {

    use TResponse;

    protected $BusinessPartnerService;

    public function __construct($crudService, $environment, BusinessPartnerService $BusinessPartnerService) {
        parent::__construct($crudService, $environment);
        $this->BusinessPartnerService = $BusinessPartnerService;
    }

    public function getBusinessPartner(Request $request, Response $response){
        try {
            $data = $this->BusinessPartnerService->getBusinessPartner();
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getOperator(Request $request, Response $response){
        try {
            $data = $this->BusinessPartnerService->getOperator();
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getPartnerClassification(Request $request, Response $response){
        try {
            $data = $this->BusinessPartnerService->getPartnerClassification();
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getTypeOfPartner(Request $request, Response $response){
        try {
            $data = $this->BusinessPartnerService->getTypeOfPartner();
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getMarketSegment(Request $request, Response $response){
        try {
            $data = $this->BusinessPartnerService->getMarketSegment();
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getBranchOfActivity(Request $request, Response $response){
        try {
            $data = $this->BusinessPartnerService->getBranchOfActivity();
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getTypeOfActivity(Request $request, Response $response){
        try {
            $data = $this->BusinessPartnerService->getTypeOfActivity();
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getCountry(Request $request, Response $response){
        try {
            $data = $this->BusinessPartnerService->getCountry();
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getState(Request $request, Response $response){
        try {
            $data = $this->BusinessPartnerService->getState($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getCity(Request $request, Response $response){
        try {
            $data = $this->BusinessPartnerService->getCity($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getDistrict(Request $request, Response $response){
        try {
            $data = $this->BusinessPartnerService->getDistrict($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function findCodeDistrict(DTO\Request $request, DTO\Response $response) {
        try{
            $codeFound = $this->BusinessPartnerService->findCodeDistrict($request->getParameters());
            $dtsVal = new DataSet('codeFound', $codeFound);
            $response->addDataSet($dtsVal);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getSpecificBusinessPartner(DTO\Request $request, DTO\Response $response) {
        try{
            $partnerFound = $this->BusinessPartnerService->getSpecificBusinessPartner($request->getParameters());
            $dtsVal = new DataSet('partnerFound', $partnerFound);
            $response->addDataSet($dtsVal);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function insertNewBusinessPartner(DTO\Request $request, DTO\Response $response) {
        try {
            $partner = $this->BusinessPartnerService->insertNewBusinessPartner($request->getParameters());
            $dtsVal = new DataSet('partner', [$partner]);
            $response->addDataSet($dtsVal);
        }
        catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function updateSpecificBusinessPartner(DTO\Request $request, DTO\Response $response) {
        try {
            $partnerFound = $this->BusinessPartnerService->updateSpecificBusinessPartner($request->getParameters());
            $dtsVal = new DataSet('partnerFound', [$partnerFound]);
            $response->addDataSet($dtsVal);
        }
        catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getBusinessPartnerAddress(Request $request, Response $response){
        try {
            $data = $this->BusinessPartnerService->getBusinessPartnerAddress($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getSpecificAddress(DTO\Request $request, DTO\Response $response) {
        try{
            $addressFound = $this->BusinessPartnerService->getSpecificAddress($request->getParameters());
            $dtsVal = new DataSet('addressFound', $addressFound);
            $response->addDataSet($dtsVal);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function insertNewAddress(DTO\Request $request, DTO\Response $response) {
        try{
            $address = $this->BusinessPartnerService->insertNewAddress($request->getParameters());
            $dtsVal = new DataSet('address', [$address]);
            $response->addDataSet($dtsVal);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function deleteAddress(DTO\Request $request, DTO\Response $response) {
        try{
            $address = $this->BusinessPartnerService->deleteAddress($request->getParameters());
            $dtsVal = new DataSet('address', [$address]);
            $response->addDataSet($dtsVal);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function updateAddress(DTO\Request $request, DTO\Response $response) {
        try{
            $address = $this->BusinessPartnerService->updateAddress($request->getParameters());
            $dtsVal = new DataSet('address', [$address]);
            $response->addDataSet($dtsVal);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    // --------- FUNÇÕES DE COMUNICAÇÃO -----------------------
    public function getWayOfCommunication(Request $request, Response $response){
        try {
            $data = $this->BusinessPartnerService->getWayOfCommunication($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getListWaysOfCommunication(Request $request, Response $response){
        try {
            $data = $this->BusinessPartnerService->getListWaysOfCommunication();
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getSpecificWayOfCommunication(DTO\Request $request, DTO\Response $response) {
        try{
            $communicFound = $this->BusinessPartnerService->getSpecificWayOfCommunication($request->getParameters());
            $dtsVal = new DataSet('communicFound', $communicFound);
            $response->addDataSet($dtsVal);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function insertNewCommunicationData(DTO\Request $request, DTO\Response $response) {
        try{
            $communic = $this->BusinessPartnerService->insertNewCommunicationData($request->getParameters());
            $dtsVal = new DataSet('communic', [$communic]);
            $response->addDataSet($dtsVal);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function deleteWayOfCommunication(DTO\Request $request, DTO\Response $response) {
        try{
            $communic = $this->BusinessPartnerService->deleteWayOfCommunication($request->getParameters());
            $dtsVal = new DataSet('communic', [$communic]);
            $response->addDataSet($dtsVal);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function updateWayOfCommunication(DTO\Request $request, DTO\Response $response) {
        try{
            $communic = $this->BusinessPartnerService->updateWayOfCommunication($request->getParameters());
            $dtsVal = new DataSet('communic', [$communic]);
            $response->addDataSet($dtsVal);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    // --------- FUNÇÕES DE INTERLOCUTORES -----------------------
    public function getSectors(Request $request, Response $response){
        try {
            $data = $this->BusinessPartnerService->getSectors();
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getPositionsOfInterlocutors(Request $request, Response $response){
        try {
            $data = $this->BusinessPartnerService->getPositionsOfInterlocutors();
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getInterlocutors(Request $request, Response $response){
        try {
            $data = $this->BusinessPartnerService->getInterlocutors($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getSpecificInterlocutor(Request $request, Response $response){
        try{
            $interFound = $this->BusinessPartnerService->getSpecificInterlocutor($request->getParameters());
            $dtsVal = new DataSet('interFound', $interFound);
            $response->addDataSet($dtsVal);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function insertNewInterlocutor(Request $request, Response $response){
        try{
            $interlocutor = $this->BusinessPartnerService->insertNewInterlocutor($request->getParameters());
            $dtsVal = new DataSet('interlocutor', [$interlocutor]);
            $response->addDataSet($dtsVal);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function deleteInterlocutor(Request $request, Response $response){
        try{
            $interlocutor = $this->BusinessPartnerService->deleteInterlocutor($request->getParameters());
            $dtsVal = new DataSet('interlocutor', [$interlocutor]);
            $response->addDataSet($dtsVal);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function updateInterlocutor(Request $request, Response $response){
        try{
            $interlocutor = $this->BusinessPartnerService->updateInterlocutor($request->getParameters());
            $dtsVal = new DataSet('interlocutor', [$interlocutor]);
            $response->addDataSet($dtsVal);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    // --------- FUNÇÕES DE DADOS BANCÁRIOS -----------------------
    public function getBankDetails(Request $request, Response $response){
        try {
            $data = $this->BusinessPartnerService->getBankDetails($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getBanks(Request $request, Response $response){
        try {
            $data = $this->BusinessPartnerService->getBanks();
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getAgencies(Request $request, Response $response){
        try {
            $data = $this->BusinessPartnerService->getAgencies($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getCheckingAccount(Request $request, Response $response){
        try {
            $data = $this->BusinessPartnerService->getCheckingAccount($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getTypeOfCheckingAccount(Request $request, Response $response){
        try {
            $data = $this->BusinessPartnerService->getTypeOfCheckingAccount();
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getSpecificBankDetails(Request $request, Response $response){
        try{
            $detailsFound = $this->BusinessPartnerService->getSpecificBankDetails($request->getParameters());
            $dtsVal = new DataSet('detailsFound', $detailsFound);
            $response->addDataSet($dtsVal);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function insertNewBankDetails(Request $request, Response $response){
        try{
            $bank = $this->BusinessPartnerService->insertNewBankDetails($request->getParameters());
            $dtsVal = new DataSet('bank', [$bank]);
            $response->addDataSet($dtsVal);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function deleteBankDetails(Request $request, Response $response){
        try{
            $bank = $this->BusinessPartnerService->deleteBankDetails($request->getParameters());
            $dtsVal = new DataSet('bank', [$bank]);
            $response->addDataSet($dtsVal);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function updateBankDetails(Request $request, Response $response){
        try{
            $bank = $this->BusinessPartnerService->updateBankDetails($request->getParameters());
            $dtsVal = new DataSet('bank', [$bank]);
            $response->addDataSet($dtsVal);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getBranches(Request $request, Response $response){
         try {
            $data = $this->BusinessPartnerService->getBranches();
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getInvoiceSeries(Request $request, Response $response){
         try {
            $data = $this->BusinessPartnerService->getInvoiceSeries();
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getBillingParameter(Request $request, Response $response){
        try {
            $parameter = $this->BusinessPartnerService->getBillingParameter($request->getParameters());
            $dtsVal = new DataSet('parameter', $parameter);
            $response->addDataSet($dtsVal);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function billingParameter(Request $request, Response $response){
        try {
            $parameter = $this->BusinessPartnerService->billingParameter($request->getParameters());
            $dtsVal = new DataSet('parameter', [$parameter]);
            $response->addDataSet($dtsVal);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function sendImage(DTO\Request $request, DTO\Response $response) {
        try {
            $image = $this->BusinessPartnerService->sendImage($request->getParameters());
            $dtsVal = new DataSet('image', [$image]);
            $response->addDataSet($dtsVal);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function deleteImage(DTO\Request $request, DTO\Response $response) {
        try {
            $this->BusinessPartnerService->deleteImage($request->getParameters());
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getImagesLogotype(DTO\Request $request, DTO\Response $response) {
        try {
            $image = $this->BusinessPartnerService->getImagesLogotype($request->getParameters());
            $dtsVal = new DataSet('image', $image);
            $response->addDataSet($dtsVal);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }
}

?>