/* eslint-disable */
import {
  Http, IDictionary, Router, Loader, Metadata, IEventParam,
} from '@zeedhi/core';
import {
  AlertService, Date as ZdDate, DialogService, Form, LoadingService, Modal, ModalService, Select, Text, TextInput,
} from '@zeedhi/common';
import { TekGrid } from '@zeedhi/teknisa-components-common';
import { Utilities } from '@/util/Utilities';

export class TabInterlocutorController {
  private addInterlocutor!: Modal;

  private editionInterlocutor!: Modal;

  public BPController = Loader.getInstance('BusinessPartnerController');

  private NRSEQINTERLOCUTOR: any;

  public setFilterGrid() {
    const NRPARCNEGOCIO = this.BPController.currentRow.NRPARCNEGOCIO;
    const grid = Metadata.getInstance<TekGrid>('tekGrid-tabInterlocutor');
    grid.datasource.setFilter({
      NRPARCNEGOCIO: NRPARCNEGOCIO,
    });
    grid.datasource.get();
  }

  public validate({ component }: any) {
    const nameForm = component.name.split('_')[0];
    this.validateCEP(nameForm);
  }

  public async validateCEP(nameForm: string) {
    const CEP = Metadata.getInstance<TextInput>(`${nameForm}-cep`).value.replace('-', '');
    const result = await this.BPController.searchCep(CEP);

    if (CEP) {
      (this.BPController.searchCep(CEP) as any).then(async (response: IDictionary) => {
        const addressFound = response.data.dataset.ENDERECO;

        if (addressFound) {
          Metadata.getInstance<TextInput>(`${nameForm}-address`).value = (addressFound.DSENDERECO) ? addressFound.DSENDERECO : '';
          await Metadata.getInstance<Select>(`${nameForm}-country`).setValue((addressFound.CDPAIS) ? addressFound.CDPAIS : '');
          await Metadata.getInstance<Select>(`${nameForm}-state`).setValue((addressFound.SGESTADO) ? addressFound.SGESTADO : '');
          await Metadata.getInstance<Select>(`${nameForm}-city`).setValue((addressFound.CDMUNICIPIO) ? addressFound.CDMUNICIPIO : '');
          if (addressFound.CDBAIRRO === '') {
            LoadingService.show();
            Http.post('/findCodeDistrict', {
              NMBAIRRO: addressFound.NMBAIRRO,
              SGESTADO: addressFound.SGESTADO,
              CDPAIS: addressFound.CDPAIS,
              CDMUNICIPIO: addressFound.CDMUNICIPIO,
            }).then((response: IDictionary) => {
              response.data.dataset.codeFound.forEach((codeFound: IDictionary) => {
                Metadata.getInstance<Select>(`${nameForm}-district`).setValue((codeFound.CDBAIRRO) ? codeFound.CDBAIRRO : '');
                LoadingService.hide();
              });
            });
          }
        }
      }).catch((error: any) => {
          if (error.data) this.BPController.alertMessage(error.data.error, 'error')
          else this.BPController.alertMessage('Erro ao realizar a busca.', 'error');
          Metadata.getInstance<TextInput>(`${nameForm}-cep`).value = '';
          Metadata.getInstance<TextInput>(`${nameForm}-address`).value =  '';
          Metadata.getInstance<Select>(`${nameForm}-country`).value = '';
          Metadata.getInstance<Select>(`${nameForm}-state`).value = '';
          Metadata.getInstance<Select>(`${nameForm}-city`).value = '';
          Metadata.getInstance<Select>(`${nameForm}-district`).value = '';
          LoadingService.hide();
      });
    }
    await (nameForm === 'formInterlocutorAddress') ? this.changeStateToEnabledModalInsertion() : this.changeStateToEnabledModalEdition();
    console.log(result);
  }

  public alertMessages(message: string, type: string) {
    AlertService.show({
      name: 'basic-alert',
      text: message,
      top: true,
      left: false,
      timeout: 3000,
      color: type,
    });
  }

  public dialogMessage(message: string) {
    DialogService.show({
      name: 'warning-dialog',
      type: 'warning',
      title: 'Erro!',
      text: message,
    });
  }

  public showDeleteDialog({ event } : any) {
    event.preventDefault();

    DialogService.show({
      name: 'buttons-dialog',
      type: 'warning',
      title: 'Excluir Interlocutor',
      text: 'Todas as informações serão perdidas se concluir está ação. Deseja continuar?',
      buttons: [
        {
          name: 'button-no',
          component: 'ZdButton',
          label: 'Não',
          events: {
            click: () => DialogService.hide(),
          },
          outline: true,
        },
        {
          name: 'button-yes',
          component: 'ZdButton',
          label: 'Sim',
          events: {
            click: '{{TabInterlocutorController.deleteInterlocutor}}'
          },
        },
      ],
    });
  }

  public async deleteInterlocutor() {
    const grid = Metadata.getInstance<TekGrid>('tekGrid-tabInterlocutor');
    const NRS = (grid.selectedRows.map((element: any) => element.NRSEQINTERLOCUTOR)).toString();
    LoadingService.show();
    await Http.post('/deleteInterlocutor', {
      NRSEQINTERLOCUTOR: NRS,
      NRPARCNEGOCIO: this.BPController.currentRow.NRPARCNEGOCIO,
    }).then(() => {
        this.alertMessages('Interlocutor excluído com sucesso', 'success');
        grid.datasource.get();
        grid.selectedRows = [];
        DialogService.hide();
        LoadingService.hide();
    }).catch((error: any) => {
      Utilities.showErrorMessage(error);
      LoadingService.hide();
    });
  }

  // Funções do Modal de Adicionar um novo interlocutor
  public async openModalAdd() {
    this.addInterlocutor = await ModalService.createFromJson('BusinessPartner/Modal/modal-add-interlocutor', true);
    this.addInterlocutor.show();
  }

  public closeModalAdd() {
    this.addInterlocutor.hide();
    this.addInterlocutor?.destroy();
  }

  public onMountNameModal() {
    Metadata.getInstance<Text>('nameOfCorporate-addInterlocutor').text = this.BPController.NAMEOFCORPORATE;
  }

  public async changeStateToEnabledModalInsertion() {
    const selectCountry = Metadata.getInstance<Select>('formInterlocutorAddress-country');
    const selectState = Metadata.getInstance<Select>('formInterlocutorAddress-state');

    if (!selectCountry.value) {
      selectState.disabled = true;
      selectState.value = '';
    } else {
      selectState.disabled = false;
      selectState.datasource.setFilter({
        CDPAIS: selectCountry.value,
      });
    }
    await this.changeCityToEnabledModalInsertion();
  }

  public async changeCityToEnabledModalInsertion() {
    const selectCountry = Metadata.getInstance<Select>('formInterlocutorAddress-country');
    const selectState = Metadata.getInstance<Select>('formInterlocutorAddress-state');
    const selectCity = Metadata.getInstance<Select>('formInterlocutorAddress-city');

    if (!selectState.value) {
      selectCity.disabled = true;
      selectCity.value = '';
    } else {
      selectCity.disabled = false;
      selectCity.datasource.setFilter({
        CDPAIS: selectCountry.value,
        SGESTADO: selectState.value,
      });
    }
    await this.changeDistrictToEnabledModalInsertion();
  }

  public async changeDistrictToEnabledModalInsertion() {
    const selectCountry = Metadata.getInstance<Select>('formInterlocutorAddress-country');
    const selectState = Metadata.getInstance<Select>('formInterlocutorAddress-state');
    const selectCity = Metadata.getInstance<Select>('formInterlocutorAddress-city');
    const selectDistrict = Metadata.getInstance<Select>('formInterlocutorAddress-district');

    if (!selectCity.value) {
      selectDistrict.disabled = true;
      selectDistrict.value = '';
    } else {
      selectDistrict.disabled = false;
      selectDistrict.datasource.setFilter({
        CDPAIS: selectCountry.value,
        SGESTADO: selectState.value,
        CDMUNICIPIO: selectCity.value
      });
    }
  }

  public insertNewInterlocutor() {
    const formInter = Metadata.getInstance<Form>('form-addInterlocutor');
    const formContato = Metadata.getInstance<Form>('formAddContacts');
    const formEndereco = Metadata.getInstance<Form>('formInterlocutorAddress-address');
    
    const formInterValido = formInter.validate();
    const formContatoValido = formContato.validate();
    const formEnderecoValido = formEndereco.validate();
    
    const grid = Metadata.getInstance<TekGrid>('tekGrid-tabInterlocutor');
    let CPF = Metadata.getInstance<TextInput>('form-interlocutorCpf').value.replace(/[^0-9]/g, '');

    if (formInterValido && formContatoValido && formEnderecoValido) {
        LoadingService.show();
        Http.post('/insertNewInterlocutor', {
        NRPARCNEGOCIO: this.BPController.currentRow.NRPARCNEGOCIO,
        NMINTERLOCUTOR: Metadata.getInstance<TextInput>('form-interlocutorName').value,
        EMAILINTERLOC: Metadata.getInstance<TextInput>('form-interlocutorEmail').value,
        NRTELEFONE1: Metadata.getInstance<TextInput>('form-interlocutorTelephone1').value,
        NRTELEFONE2: Metadata.getInstance<TextInput>('form-interlocutorTelephone2').value,
        NRTELEFONE3: Metadata.getInstance<TextInput>('form-interlocutorTelephone3').value,
        NRTELEFONE4: Metadata.getInstance<TextInput>('form-interlocutorTelephone4').value,
        CDCARGOINTERLOC: Metadata.getInstance<Select>('form-interlocutorPositions').value,
        DTNASCIMENTO: Metadata.getInstance<ZdDate>('form-birthDate').value,
        IDRECEBEPRESENTE: Metadata.getInstance<Select>('form-receiveGift').value,
        CDPAIS: Metadata.getInstance<Select>('formInterlocutorAddress-country').value,
        SGESTADO: Metadata.getInstance<Select>('formInterlocutorAddress-state').value,
        CDMUNICIPIO: Metadata.getInstance<Select>('formInterlocutorAddress-city').value,
        CDBAIRRO: Metadata.getInstance<Select>('formInterlocutorAddress-district').value,
        NRCEPINTERLOCUTOR: Metadata.getInstance<TextInput>('formInterlocutorAddress-cep').value,
        DSENDEINTERLOCUTOR: Metadata.getInstance<TextInput>('formInterlocutorAddress-address').value,
        DSCOMPINTERLOCUTOR: Metadata.getInstance<TextInput>('formInterlocutorAddress-addressComplement').value,
        NRENDEINTERLOCUTOR: Metadata.getInstance<TextInput>('formInterlocutorAddress-number').value,
        CDOPERINCLUSAO: localStorage.getItem('CDOPERADOR'),
        CDSETOR: Metadata.getInstance<Select>('form-interlocutorSector').value,
        NRCPFINTERLOC: CPF,
        IDTPSIGNATARIO: Metadata.getInstance<Select>('form-kindOfSlut').value,
      }).then(() => {
          this.alertMessages('Interlocutor adicionado com sucesso!', 'success');
          this.closeModalAdd();
          grid.datasource.get();
          LoadingService.hide();
      }).catch((error: any) => {
        Utilities.showErrorMessage(error);
        LoadingService.hide();
      });
    } else {
      this.alertMessages('Por favor, preencha todos os campos obrigatórios(*)!', 'error');
    }
  }

  // Funções do modal de edição de interlocutor
  public async openModalEdition({ row }: any) {
    this.editionInterlocutor = await ModalService.createFromJson('BusinessPartner/Modal/modal-edition-interlocutor', true);
    this.NRSEQINTERLOCUTOR = row.NRSEQINTERLOCUTOR;
    await this.editionInterlocutor.show();
  }

  public closeModalEdition() {
    this.editionInterlocutor.hide();
    this.editionInterlocutor?.destroy();
  }

  public async mountInformationOfInterlocutor() {
    const NRSEQINTERLOCUTOR = this.NRSEQINTERLOCUTOR;
    let response1 : any;
    const NAMEOFCORPORATE = this.BPController.NAMEOFCORPORATE;
    console.log(NAMEOFCORPORATE);
    LoadingService.show();
    await Http.post('/specificInterlocutor', { NRSEQINTERLOCUTOR }).then((response: IDictionary) =>{
      response1 = response.data.dataset.interFound;
      LoadingService.hide();
    }).catch((error: any) => {
      Utilities.showErrorMessage(error);
      LoadingService.hide();
    });
    response1.forEach(async (data: IDictionary) => {
      Metadata.getInstance<Text>('NRSEQINTERLOCUTOR').text = data.NRSEQINTERLOCUTOR;
      Metadata.getInstance<Text>('nameOfCorporate-editionInterlocutor').text = `${data.NMINTERLOCUTOR} << ${NAMEOFCORPORATE}`;
      Metadata.getInstance<TextInput>('formEditionInterlocutor-interlocutorName').value = data.NMINTERLOCUTOR;
      Metadata.getInstance<Select>('formEditionInterlocutor-kindOfSlut').setValue(data.IDTPSIGNATARIO);
      Metadata.getInstance<TextInput>('formEditionInterlocutor-interlocutorCpf').value = data.NRCPFINTERLOC;
      Metadata.getInstance<ZdDate>('formEditionInterlocutor-birthDate').value = data.DTNASCIMENTO;
      Metadata.getInstance<Select>('formEditionInterlocutor-receiveGift').setValue(data.IDRECEBEPRESENTE);
      Metadata.getInstance<Select>('formEditionInterlocutor-interlocutorSector').setValue(data.CDSETOR);
      Metadata.getInstance<Select>('formEditionInterlocutor-interlocutorPosition').setValue(data.CDCARGOINTERLOC);
      Metadata.getInstance<TextInput>('formEditionContacts-interlocutorEmail').value = data.EMAILINTERLOC;
      Metadata.getInstance<TextInput>('formEditionContacts-interlocutorTelephone1').value = data.NRTELEFONE1;
      Metadata.getInstance<TextInput>('formEditionContacts-interlocutorTelephone2').value = data.NRTELEFONE2;
      Metadata.getInstance<TextInput>('formEditionContacts-interlocutorTelephone3').value = data.NRTELEFONE3;
      Metadata.getInstance<TextInput>('formEditionContacts-interlocutorTelephone1').value = data.NRTELEFONE4;
      Metadata.getInstance<TextInput>('formEditionInterlocutorAddress-cep').value = data.NRCEPINTERLOCUTOR;
      await Metadata.getInstance<Select>('formEditionInterlocutorAddress-country').setValue(data.CDPAIS);
      await Metadata.getInstance<Select>('formEditionInterlocutorAddress-state').setValue(data.SGESTADO);
      await Metadata.getInstance<Select>('formEditionInterlocutorAddress-city').setValue(data.CDMUNICIPIO);
      Metadata.getInstance<TextInput>('formEditionInterlocutorAddress-address').value = data.DSENDEINTERLOCUTOR;
      Metadata.getInstance<TextInput>('formEditionInterlocutorAddress-number').value = data.NRENDEINTERLOCUTOR;
      Metadata.getInstance<TextInput>('formEditionInterlocutorAddress-addressComplement').value = data.DSCOMPINTERLOCUTOR;
      await Metadata.getInstance<Select>('formEditionInterlocutorAddress-district').setValue(data.CDBAIRRO);
    });
    await this.changeStateToEnabledModalEdition();
  }

  public async changeStateToEnabledModalEdition() {
    const selectCountry = Metadata.getInstance<Select>('formEditionInterlocutorAddress-country');
    const selectState = Metadata.getInstance<Select>('formEditionInterlocutorAddress-state');

    if (!selectCountry.value) {
      selectState.disabled = true;
      selectState.value = '';
    } else {
      selectState.disabled = false;
      selectState.datasource.setFilter({
        CDPAIS: selectCountry.value,
      });
    }
    await this.changeCityToEnabledModalEdition();
  }

  public async changeCityToEnabledModalEdition() {
    const selectCountry = Metadata.getInstance<Select>('formEditionInterlocutorAddress-country');
    const selectState = Metadata.getInstance<Select>('formEditionInterlocutorAddress-state');
    const selectCity = Metadata.getInstance<Select>('formEditionInterlocutorAddress-city');

    if (!selectState.value) {
      selectCity.disabled = true;
      selectCity.value = '';
    } else {
      selectCity.disabled = false;
      selectCity.datasource.setFilter({
        CDPAIS: selectCountry.value,
        SGESTADO: selectState.value,
      });
    }
    await this.changeDistrictToEnabledModalEdition();
  }

  public async changeDistrictToEnabledModalEdition() {
    const selectCountry = Metadata.getInstance<Select>('formEditionInterlocutorAddress-country');
    const selectState = Metadata.getInstance<Select>('formEditionInterlocutorAddress-state');
    const selectCity = Metadata.getInstance<Select>('formEditionInterlocutorAddress-city');
    const selectDistrict = Metadata.getInstance<Select>('formEditionInterlocutorAddress-district');

    if (!selectCity.value) {
      selectDistrict.disabled = true;
      selectDistrict.value = '';
    } else {
      selectDistrict.disabled = false;
      selectDistrict.datasource.setFilter({
        CDPAIS: selectCountry.value,
        SGESTADO: selectState.value,
        CDMUNICIPIO: selectCity.value
      });
    }
  }

  public updateInterlocutor() {
    const formInter = Metadata.getInstance<Form>('formEditionInterlocutor');
    const grid = Metadata.getInstance<TekGrid>('tekGrid-tabInterlocutor');
    const CPF = Metadata.getInstance<TextInput>('formEditionInterlocutor-interlocutorCpf').value;

    if (formInter.validate()) {
      LoadingService.show();
      Http.post('/updateInterlocutor', {
        NRPARCNEGOCIO: this.BPController.currentRow.NRPARCNEGOCIO,
        NRSEQINTERLOCUTOR: Metadata.getInstance<Text>('NRSEQINTERLOCUTOR').text,
        NMINTERLOCUTOR: Metadata.getInstance<TextInput>('formEditionInterlocutor-interlocutorName').value,
        EMAILINTERLOC: Metadata.getInstance<TextInput>('formEditionContacts-interlocutorEmail').value,
        NRTELEFONE1: Metadata.getInstance<TextInput>('formEditionContacts-interlocutorTelephone1').value,
        NRTELEFONE2: Metadata.getInstance<TextInput>('formEditionContacts-interlocutorTelephone2').value,
        NRTELEFONE3: Metadata.getInstance<TextInput>('formEditionContacts-interlocutorTelephone3').value,
        NRTELEFONE4: Metadata.getInstance<TextInput>('formEditionContacts-interlocutorTelephone4').value,
        CDCARGOINTERLOC: Metadata.getInstance<Select>('formEditionInterlocutor-interlocutorPosition').value,
        DTNASCIMENTO: Metadata.getInstance<ZdDate>('formEditionInterlocutor-birthDate').value,
        IDRECEBEPRESENTE: Metadata.getInstance<Select>('formEditionInterlocutor-receiveGift').value,
        CDPAIS: Metadata.getInstance<Select>('formEditionInterlocutorAddress-country').value,
        SGESTADO: Metadata.getInstance<Select>('formEditionInterlocutorAddress-state').value,
        CDMUNICIPIO: Metadata.getInstance<Select>('formEditionInterlocutorAddress-city').value,
        CDBAIRRO: Metadata.getInstance<Select>('formEditionInterlocutorAddress-district').value,
        NRCEPINTERLOCUTOR: Metadata.getInstance<TextInput>('formEditionInterlocutorAddress-cep').value,
        DSENDEINTERLOCUTOR: Metadata.getInstance<TextInput>('formEditionInterlocutorAddress-address').value,
        DSCOMPINTERLOCUTOR: Metadata.getInstance<TextInput>('formEditionInterlocutorAddress-addressComplement').value,
        NRENDEINTERLOCUTOR: Metadata.getInstance<TextInput>('formEditionInterlocutorAddress-number').value,
        CDOPERULTATU: localStorage.getItem('CDOPERADOR'),
        CDSETOR: Metadata.getInstance<Select>('formEditionInterlocutor-interlocutorSector').value,
        NRCPFINTERLOC: (CPF === null) ? null : CPF.replace(/[^0-9]/g, ''),
        IDTPSIGNATARIO: Metadata.getInstance<Select>('formEditionInterlocutor-kindOfSlut').value,
      }).then(() => {
          this.alertMessages('Interlocutor alterado com sucesso!', 'success');
          this.closeModalEdition();
          grid.datasource.get();
          LoadingService.hide();
      }).catch((error: any) => {
        Utilities.showErrorMessage(error);
        LoadingService.hide();
      });
    } else {
      this.alertMessages('Por favor, preencha todos os campos obrigatórios(*)!', 'error');
    }
  }
  
  public tipoSignatarioOnChange ({ component } : IEventParam<Select>) {
    const campoCpf = Metadata.getInstance<TextInput>('form-interlocutorCpf');
    const campoEmail = Metadata.getInstance<TextInput>('form-interlocutorEmail');
    const campoDataNasc = Metadata.getInstance<ZdDate>('form-birthDate');
    
    const campos = [campoCpf, campoEmail, campoDataNasc];
    
    if (['T', 'S'].includes(component.value)) {
      campos.forEach((campo) => {
        campo.cssClass = '';
        campo.addValidation('required', {});
      });
    }
    else {
      campos.forEach((campo) => {
        campo.clearValidations();
        campo.cssClass = 'not-required';
      });
    }
  }
}
