import {
  Metadata,
} from '@zeedhi/core';
import {
  DialogService, AlertService, FileInput,
} from '@zeedhi/common';

export class Utilities {
    public static showErrorMessage(error : any) {
        console.error(error);
        let msg = '';
        if (error.response && error.response.data && error.response.data.error) {
            msg = error.response.data.error;
        } else {
            msg = error;
        }
        if (!msg) {
            msg = 'Ocorreu um erro inesperado. Por favor, entre em contato com o suporte.';
        }
        DialogService.show({
            name: 'error_dialog',
            type: 'error',
            title: 'Erro',
            text: msg,
        });
    }

    public static showSuccessMessage() {
        AlertService.show({
            name: 'basic-alert',
            text: 'Processo realizado com sucesso!',
            top: true,
            left: false,
            color: 'success',
            timeout: 2000,
            buttonsSlot: [
                {
                  name: 'undo-button',
                  component: 'ZdButton',
                  icon: true,
                  iconName: 'close',
                  color: 'white',
                  events: {
                    click: () => { AlertService.hide(); },
                  },
                },
            ],
        });
    }

    public static async buildArrayToUpload(nomeComponente: string) {
        const file = Metadata.getInstance<FileInput>(nomeComponente).value;
        if (file) {
          const base64file = await this.toBase64(file);
            return [{
                b64File: base64file,
                lastModified: file.lastModified,
                name: file.name,
                size: file.size,
                type: file.type,
                webkitRelativePath: file.webkitRelativePath,
            }];
        }
        return [];
    }

    /* public static async buildArrayToUploadPromise(nomeComponente: string) {
        const file = Metadata.getInstance<FileInput>(nomeComponente).value;
        return new Promise((resolve, reject) => {
            if (file) {
                this.toBase64(file).then((base64file) => {
                    resolve([{
                        b64File: base64file,
                        lastModified: file.lastModified,
                        name: file.name,
                        size: file.size,
                        type: file.type,
                        webkitRelativePath: file.webkitRelativePath,
                    }]);
                }).catch((error) => {
                    reject(error);
                });
            }
            else {
                resolve([]);
            }
        });
    }; */

    public static async toBase64(file: any) {
        return new Promise((resolve, reject) => {
            const reader = new FileReader();
            reader.readAsDataURL(file);
            reader.onload = () => resolve(reader.result);
            reader.onerror = (error) => reject(error);
        });
    }
}
